@@ -6,10 +6,14 @@
 
 #import "HBQueueItemView.h"
 
+@class HBQueueWorker;
+
 NS_ASSUME_NONNULL_BEGIN
 
 @interface HBQueueItemWorkingView : HBQueueItemView
 
+@property (nonatomic) HBQueueWorker *worker;
+
 @end
 
 NS_ASSUME_NONNULL_END
